BEGIN;

-- 1.0.1 -> 1.0.2 
-- Erweiterung des Datenmodells
ALTER TABLE master_tbl DISABLE TRIGGER USER;
SET ROLE :db_adm;

INSERT INTO db_history (beschreibung, zeitpunkt)
VALUES ('1.0.2/99_views.sql', current_timestamp);

CREATE OR REPLACE VIEW rg_ziele_tbl_view
AS SELECT rg_ziele_tbl.* FROM rg_ziele_tbl
    INNER JOIN master_tbl
    ON         rg_ziele_tbl.master_id = master_tbl.id
WHERE
    master_tbl.bearbeiter_id = getuserid()
    OR master_tbl.id IN (
        SELECT nm.master_id from nm_benutzer_master_tbl nm
        WHERE nm.benutzer_id IN (
            SELECT nm2.gruppe_id from nm_benutzer_gruppe_tbl nm2 
            WHERE nm2.benutzer_id = getuserid()
        )
    )
    OR pg_has_role('admin','MEMBER');

CREATE OR REPLACE RULE rg_ziele_tbl_update_rule AS ON UPDATE TO rg_ziele_tbl_view
DO INSTEAD UPDATE rg_ziele_tbl SET
    fp_ziel = NEW.fp_ziel,
    fp_ziel_erreicht = NEW.fp_ziel_erreicht,
    fp_ziel_sonstiges = NEW.fp_ziel_sonstiges,
    fp_ziel_beschreibung = NEW.fp_ziel_beschreibung,
    fp_leistung_teilnehmer = NEW.fp_leistung_teilnehmer,
    fp_leistung_jmd = NEW.fp_leistung_jmd,
    fp_datum_vereinbarung = NEW.fp_datum_vereinbarung,
    fp_datum_umsetzung = NEW.fp_datum_umsetzung,
    fp_uziel1 = NEW.fp_uziel1,
    fp_uziel1_erreicht = NEW.fp_uziel1_erreicht,
    fp_uziel1_angebot = NEW.fp_uziel1_angebot,
    ua_uziel1_art = NEW.ua_uziel1_art,
    ua_uziel1_datum_start = NEW.ua_uziel1_datum_start,
    ua_uziel1_datum_ende = NEW.ua_uziel1_datum_ende,
    fp_externe_einrichtung_1_name = NEW.fp_externe_einrichtung_1_name,
    fp_externe_einrichtung_1_datum = NEW.fp_externe_einrichtung_1_datum,
    fp_uziel2 = NEW.fp_uziel2,
    fp_uziel2_erreicht = NEW.fp_uziel2_erreicht,
    fp_uziel2_angebot = NEW.fp_uziel2_angebot,
    ua_uziel2_art = NEW.ua_uziel2_art,
    ua_uziel2_datum_start = NEW.ua_uziel2_datum_start,
    ua_uziel2_datum_ende = NEW.ua_uziel2_datum_ende,
    fp_externe_einrichtung_2_name = NEW.fp_externe_einrichtung_2_name,
    fp_externe_einrichtung_2_datum = NEW.fp_externe_einrichtung_2_datum,
    fp_uziel3 = NEW.fp_uziel3,
    fp_uziel3_erreicht = NEW.fp_uziel3_erreicht,
    fp_uziel3_angebot = NEW.fp_uziel3_angebot,
    ua_uziel3_art = NEW.ua_uziel3_art,
    ua_uziel3_datum_start = NEW.ua_uziel3_datum_start,
    ua_uziel3_datum_ende = NEW.ua_uziel3_datum_ende,
    fp_externe_einrichtung_3_name = NEW.fp_externe_einrichtung_3_name,
    fp_externe_einrichtung_3_datum = NEW.fp_externe_einrichtung_3_datum
WHERE id = NEW.id;

CREATE OR REPLACE RULE rg_ziele_tbl_delete_rule AS ON DELETE TO rg_ziele_tbl_view
    DO INSTEAD NOTHING;

CREATE OR REPLACE RULE rg_ziele_tbl_insert_rule AS ON INSERT TO rg_ziele_tbl_view
    DO INSTEAD NOTHING;

GRANT SELECT ON rg_ziele_tbl_view TO GROUP :cm_group;
GRANT UPDATE ON rg_ziele_tbl_view TO GROUP :cm_group;
GRANT SELECT ON rg_ziele_tbl_view TO GROUP :admin_group;

CREATE OR REPLACE VIEW rg_ziele_tbl_anonym_view
AS SELECT
    id,
    master_id,
    uuid_id,
    fp_ziel,
    fp_ziel_erreicht,
    NULL::VARCHAR(60) AS fp_ziel_sonstiges,
    NULL::TEXT AS fp_ziel_beschreibung,
    NULL::TEXT AS fp_leistung_teilnehmer,
    NULL::TEXT AS fp_leistung_jmd,
    fp_datum_vereinbarung,
    fp_datum_umsetzung,
    NULL::VARCHAR(60) AS fp_uziel1,
    fp_uziel1_erreicht,
    fp_uziel1_angebot,
    NULL::VARCHAR(60) AS ua_uziel1_art,
    ua_uziel1_datum_start,
    ua_uziel1_datum_ende,
    NULL::VARCHAR(60) AS fp_externe_einrichtung_1_name,
    fp_externe_einrichtung_1_datum,
    NULL::VARCHAR(60) AS fp_uziel2,
    fp_uziel2_erreicht,
    fp_uziel2_angebot,
    NULL::VARCHAR(60) AS ua_uziel2_art,
    ua_uziel2_datum_start,
    ua_uziel2_datum_ende,
    NULL::VARCHAR(60) AS fp_externe_einrichtung_2_name,
    fp_externe_einrichtung_2_datum,
    NULL::VARCHAR(60) AS fp_uziel3,
    fp_uziel3_erreicht,
    fp_uziel3_angebot,
    NULL::VARCHAR(60) AS ua_uziel3_art,
    ua_uziel3_datum_start,
    ua_uziel3_datum_ende,
    NULL::VARCHAR(60) AS fp_externe_einrichtung_3_name,
    fp_externe_einrichtung_3_datum FROM rg_ziele_tbl_view;

CREATE OR REPLACE RULE rg_ziele_tbl_anonym_delete_rule AS ON DELETE TO rg_ziele_tbl_anonym_view
    DO INSTEAD NOTHING;

CREATE OR REPLACE RULE rg_ziele_tbl_anonym_insert_rule AS ON INSERT TO rg_ziele_tbl_anonym_view
    DO INSTEAD NOTHING;

GRANT SELECT ON rg_ziele_tbl_anonym_view TO GROUP :cm_group;
GRANT SELECT ON rg_ziele_tbl_anonym_view TO GROUP :admin_group;

-- Finish
SET ROLE postgres;
ALTER TABLE master_tbl ENABLE TRIGGER ALL;
COMMIT;
