import sys
import logging
import codecs
from optparse import OptionParser

from mpulsweb.lib.config import MpulsAppConfig


def load_mpuls_config(filename):
    return MpulsAppConfig(filename)


def logbook_kinds_from_config(config):
    for logbook_type in config.get("logbook", "types"):
        if logbook_type["db_field"] == "art":
            return logbook_type["options"]
    raise ValueError("Could not find db_field 'art' in logbook types config")


def write_logbook_inserts(config, outfile):
    outfile.write("-- Logbook categories\n")

    outfile.write("-- special entries\n")
    outfile.write("INSERT INTO ka_logbuch_art_tbl (id, beschreibung)"
                  " VALUES (0, 'Automatischer Eintrag');\n")

    for group in logbook_kinds_from_config(config):
        outfile.write("-- %s\n" % (group["label"],))
        for option_id, label in group["options"]:
            outfile.write("INSERT INTO ka_logbuch_art_tbl (id, beschreibung)"
                          " VALUES (%s, '%s');\n" % (option_id, label))

    # currently not configurable, but always a part of the SQL-file
    # we're generating:
    outfile.write("\n\n--\n")
    outfile.write("-- Logbuch typ\n")
    outfile.write("--\n")
    for option_id, label in [(0, 'nicht aufsuchend'),
                             (1, 'aufsuchend'),
                             (-1, 'Keine Angabe')]:
        outfile.write("INSERT INTO ka_logbuch_typ_tbl (id, beschreibung)"
                      " VALUES (%d, '%s');\n" % (option_id, label))


def main():
    parser = OptionParser()
    parser.set_defaults(verbosity="WARNING")
    parser.add_option("--config-file",
                      help="The name of application's JSON config file")
    parser.add_option("--verbosity",
                      choices=("CRITICAL", "ERROR", "WARNING", "INFO", "DEBUG"),
                      help=("Verbosity of diagnostics (one of CRITICAL, ERROR,"
                            " WARNING, INFO, DEBUG). Default: WARNING."))

    options, rest = parser.parse_args()

    logging.basicConfig(level=getattr(logging, options.verbosity))

    if options.config_file is None:
        print >>sys.stderr, "A config filename must be given"
        exit(1)

    config = load_mpuls_config(options.config_file)

    write_logbook_inserts(config, codecs.getwriter("utf-8")(sys.stdout))


main()


