# -*- coding: utf-8 -*-
#
# Copyright 2007, 2008 Intevation GmbH, Germany, <info@intevation.de>
#
# This file is part of mpuls WASKA (CoMPUter-based case fiLeS -
# Web-Anwendungs-Server fuer Kompetenzagenturen).
#
# mpuls WASKA is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# mpuls WASKA is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with mpuls WASKA. If not, see <http://www.gnu.org/licenses/>.
#
# mpuls WASKA has been developed on behalf of the
# Projekttraeger im Deutschen Zentrum fuer Luft- und Raumfahrt e.V. (PT-DLR)
# within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
# the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and
# European Social Fund resources.
#
# Authors:
# Sascha L. Teichmann <teichmann@intevation.de>
#

import logging
import formencode

from pylons import url
from pylons.controllers.util import redirect

from mpulsweb.lib.translation import _

import paste

from mpulsweb.lib.base import BaseController, c, h, render, \
    request, g, render_htmlfill, abort_unless_POST
from mpulsweb.lib.security import checkRole
from mpulsweb.lib.validators import UploadGlobalDocumentForm, \
    UploadGlobalDocumentWDescForm, \
    RenameDocumentForm, \
    RenameDocumentWDescForm
from mpulsweb.model.document import Document, listDocuments, deleteDocument, \
    renameDocument


log = logging.getLogger(__name__)


class DocumentController(BaseController):

    @checkRole(('admin', 'cm'))
    def index(self):
        redirect(url(controller='document', action='globalOverview'))

    @checkRole(('admin', 'cm'))
    def globalOverview(self):
        try:
            c.files = listDocuments()
        except Exception, e:
            log.exception(e)
            raise
        return render('/documents/global_overview.mako')

    @checkRole('admin')
    def globalUpload(self):
        return render('/documents/global_upload.mako')

    @checkRole('admin')
    def globalUploadAction(self):
        if g.mpuls_config.is_enabled("module", "documents-description"):
            validator = UploadGlobalDocumentWDescForm()
        else:
            validator = UploadGlobalDocumentForm()
        try:
            result = validator.to_python(request.params)
            doc = Document()
            filename = result['file']['filename']
            content = result['file']['content']
            if result['name']:
                filename = result['name']
            if g.mpuls_config.is_enabled("module", "documents-description"):
                doc.create(
                    filename, content, description=result['description'])
            else:
                doc.create(filename, content)
            c.dialog_title = _(u"Document added!")
            c.dialog_text = _("Please click OK to continue.")
            c.url_ok = h.url(controller="document",
                             action="globalOverview")
            return render('/documents/dialogs/success_documents.mako')
        except formencode.Invalid, error:
            c.form_result = error.value
            c.form_errors = error.error_dict or {}
            log.debug(c.form_result)
            log.warn("Invalid form data for document %s" % c.form_errors)
            form = render('/documents/global_upload.mako')
            return render_htmlfill(form, defaults=c.form_result,
                                   auto_insert_errors=False,
                                   errors=c.form_errors)

    @checkRole(('admin', 'cm'))
    def globalShow(self, id):
        id = self._checkInt(id)
        try:
            document = Document(id)
            document.load()
            data = paste.fileapp.DataApp(document.data,
                                         content_type=document.mime,
                                         cache_control='must-revalidate',
                                         pragma='public')
            return data(request.environ, self.start_response)
        except Exception, e:
            log.exception(e)
            # FIXME case ist not defined!!!
            redirect(url(controller="case", action="documents", id=case))

    @checkRole('admin')
    def globalDelete(self, id, confirmed='0'):
        id = self._checkInt(id)
        confirmed = self._checkBool(confirmed)
        if confirmed == 1:
            abort_unless_POST()
            try:
                deleteDocument(id)
            except Exception, e:
                log.exception(e)
                return self.globalOverview()
            c.url_ok = h.url(controller="document",
                             action="globalOverview")
            c.dialog_title = _(u"Document deleted!")
            c.dialog_text = _("Please click OK to continue.")
            return render('/documents/dialogs/delete_document_success.mako')
        else:
            docs = listDocuments()

            for doc in docs:
                if int(doc.id) == id:
                    name = doc.getName()
                    description = doc.description
                    break
            if not name:
                name = ""
            if not description:
                description = ""

            c.context = "../main.mako"
            c.dialog_title = _(u"Delete document?")
            c.dialog_text = _(
                u"Do you want to delete the document '%s' and "
                u"irrevocably lose the data?") % name
            c.url_yes = h.url(controller='document',
                              action='globalDelete', id=id, confirmed=1)
            c.url_no = h.url(controller='document',
                             action='globalOverview')
            return render('/documents/dialogs/confirm.mako')

    @checkRole('admin')
    def globalRename(self, id):
        c.id = self._checkInt(id)

        docs = listDocuments()

        for doc in docs:
            if int(doc.id) == c.id:
                c.name = doc.getName()
                c.description = doc.description
                break

        if not c.name:
            c.name = ""
        if not c.description:
            c.description = ""

        return render('/documents/global_rename.mako')

    @checkRole('admin')
    def globalRenameAction(self, id):
        if g.mpuls_config.is_enabled("module", "documents-description"):
            validator = RenameDocumentWDescForm()
        else:
            validator = RenameDocumentForm()
        try:
            result = validator.to_python(request.params)
            if result.has_key('name'):
                filename = result['name']
            else:
                filename = ""
            if result.has_key('description'):
                desc = result['description']
            else:
                desc = ""
            renameDocument(id, filename, desc)
        except formencode.Invalid, error:
            c.id = int(id)
            c.form_result = error.value
            c.form_errors = error.error_dict or {}
            log.debug(c.form_result)
            form = render('/documents/global_rename.mako')
            return render_htmlfill(form, defaults=c.form_result,
                                   auto_insert_errors=False,
                                   errors=c.form_errors)
        return self.globalOverview()

# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
