import unittest
from datetime import timedelta

from mpulsweb.lib.helpers import human_timedelta, human_timedelta_days

class TestHumanTimeDelta(unittest.TestCase):

    def test_none_time_delta(self):
        self.assertEqual(human_timedelta(None), None)

    def test_none_time_delta_empty(self):
        self.assertEqual(human_timedelta(None, "<empty>"), "<empty>")

    def test_positive_time_delta(self):
        self.assertEqual(human_timedelta(timedelta(1)),
                         "1 Tag, 0:00:00")

    def test_negative_time_delta(self):
        self.assertEqual(human_timedelta(timedelta(-2, -3600*4 - 60*12 - 5)),
                         "-2 Tage, 4:12:05")

    def test_negative_zero_days_time_delta(self):
        self.assertEqual(human_timedelta(timedelta(0, -3600*4 - 60*12 - 5)),
                         "-4:12:05")

    def test_zero_days_time_delta(self):
        self.assertEqual(human_timedelta(timedelta(0, 3600*13 + 60*8)),
                         "13:08:00")


class TestHumanTimeDeltaDays(unittest.TestCase):

    def test_none_time_delta_days(self):
        self.assertEqual(human_timedelta_days(None), None)

    def test_none_time_delta_days_empty(self):
        self.assertEqual(human_timedelta_days(None, "<empty>"), "<empty>")

    def test_positive_time_delta_days(self):
        self.assertEqual(human_timedelta_days(timedelta(1)), "1 Tag")

    def test_negative_time_delta(self):
        self.assertEqual(human_timedelta_days(timedelta(-2)), "-2 Tage")

    def test_zero_time_delta(self):
        self.assertEqual(human_timedelta_days(timedelta(0)), "0 Tage")


if __name__ == "__main__":
    unittest.main()

