# -*- coding: utf-8 -*-
# Copyright 2009 Intevation GmbH, Germany, <info@intevation.de>
# Authors:
# Sascha L. Teichmann <teichmann@intevation.de>
#


class UUID(object):

    '''Little fake UUID class with minimal support for type 4'''

    def __init__(self, bytes):
        self.value = long(('%02x'*16) % tuple(map(ord, bytes)), 16)

    def __str__(self):
        h = '%032x' % self.value
        return '%s-%s-%s-%s-%s' % (h[:8], h[8:12], h[12:16], h[16:20], h[20:])

    def __cmp__(self, other):
        return cmp(self.value, other.value)


uuid4 = None
try:
    import uuid
    uuid4 = uuid.uuid4
except ImportError:
    try:
        import os
        os.urandom(16) # test it
        uuid4 = lambda: UUID(os.urandom(16))
    except:
        import random
        uuid4 = lambda: UUID([chr(random.randrange(256)) for i in range(16)])


class UUIDGenerator(object):

    def __init__(self):
        self.id2uuid = {}

    def generateUUID(self):
        u = uuid4()
        idx = len(self.id2uuid)
        self.id2uuid[idx] = u
        return (u, idx)

    def getUUIDforID(self, idx):
        return self.id2uuid[idx]

    def getIDforUUID(self, uuid):
        for k, v in self.id2uuid.iteritems():
            if v == uuid:
                return k
        raise KeyError()

    def clear(self):
        self.id2uuid.clear()


# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
